package com.ruoyi.abuwx.service;

import com.ruoyi.abuwx.domain.InfoOperationRecord;

import java.util.List;

/**
 * 资讯信息操作记录Service接口
 * 
 * @author lujie
 * @date 2025-01-10
 */
public interface IInfoOperationRecordService 
{
    /**
     * 查询资讯信息操作记录
     * 
     * @param id 资讯信息操作记录主键
     * @return 资讯信息操作记录
     */
    public InfoOperationRecord selectInfoOperationRecordById(Long id);

    /**
     * 查询资讯信息操作记录列表
     * 
     * @param infoOperationRecord 资讯信息操作记录
     * @return 资讯信息操作记录集合
     */
    public List<InfoOperationRecord> selectInfoOperationRecordList(InfoOperationRecord infoOperationRecord);

    /**
     * 新增资讯信息操作记录
     * 
     * @param infoOperationRecord 资讯信息操作记录
     * @return 结果
     */
    public int insertInfoOperationRecord(InfoOperationRecord infoOperationRecord);

    /**
     * 修改资讯信息操作记录
     * 
     * @param infoOperationRecord 资讯信息操作记录
     * @return 结果
     */
    public int updateInfoOperationRecord(InfoOperationRecord infoOperationRecord);

    /**
     * 批量删除资讯信息操作记录
     * 
     * @param ids 需要删除的资讯信息操作记录主键集合
     * @return 结果
     */
    public int deleteInfoOperationRecordByIds(Long[] ids);

    /**
     * 删除资讯信息操作记录信息
     * 
     * @param id 资讯信息操作记录主键
     * @return 结果
     */
    public int deleteInfoOperationRecordById(Long id);
}
